// AIOUSB.h : Header file for AIOUSB.c



#define diNone 0xFFFFFFFF
#define diFirst 0xFFFFFFFE
#define diOnly 0xFFFFFFFD

#define TIME_METHOD_NOW 0
#define TIME_METHOD_WAIT_INPUT_ENABLE 86
#define TIME_METHOD_NOW_AND_ABORT 5
#define TIME_METHOD_WHEN_INPUT_ENABLE 1



unsigned long AIOUSB_Load(void);
unsigned long AIOUSB_Unload(void);

typedef unsigned long TGetDevices(void);
typedef unsigned long TQueryDeviceInfo(unsigned long DeviceIndex, unsigned long *pPID, unsigned long *pNameSize, char *pName, unsigned long *pDIOBytes, unsigned long *pCounters);
typedef unsigned long TAIOUSB_CloseDevice(unsigned long DeviceIndex);
typedef unsigned long TClearDevices(void);
typedef unsigned long TGetDeviceUniqueStr(unsigned long DeviceIndex, unsigned long *pUIDSize, char *pUID);
typedef unsigned long TGetDeviceSerialNumber(unsigned long DeviceIndex, unsigned __int64 *pSerialNumber);
typedef unsigned long TResolveDeviceIndex(unsigned long DeviceIndex);
typedef unsigned long TGetDeviceByEEPROMByte(unsigned char Data);
typedef unsigned long TGetDeviceByEEPROMData(unsigned long StartAddress, unsigned long DataSize, unsigned char *pData);
typedef unsigned long TGetDeviceBySerialNumber(unsigned __int64 *pSerialNumber);

typedef unsigned long TAIOUSB_ClearFIFO(unsigned long DeviceIndex, unsigned long TimeMethod);
typedef unsigned long TAIOUSB_GetStreamStatus(unsigned long DeviceIndex, unsigned long *Status);
typedef unsigned long TAIOUSB_SetStreamingBlockSize(unsigned long DeviceIndex, unsigned long BlockSize);
typedef unsigned long TAIOUSB_ResetChip(unsigned long DeviceIndex);
typedef unsigned long TAIOUSB_ReloadDeviceLinks();
typedef unsigned long TAIOUSB_UploadD15LoFirmwaresByPID(char *pFirmScript);

typedef unsigned long TAIOUSB_QuerySimplePNPData(unsigned long DeviceIndex, void *pPNPData, unsigned long *pPNPDataBytes);

typedef unsigned long TCustomEEPROMRead(unsigned long DeviceIndex, unsigned long StartAddress, unsigned long *DataSize, void *pData);
typedef unsigned long TCustomEEPROMWrite(unsigned long DeviceIndex, unsigned long StartAddress, unsigned long DataSize, void *pData);
typedef unsigned long TAIOUSB_FlashRead(unsigned long DeviceIndex, unsigned long StartAddress, unsigned long *DataSize, void *Data);
typedef unsigned long TAIOUSB_FlashWrite(unsigned long DeviceIndex, unsigned long StartAddress, unsigned long DataSize, void *Data);
typedef unsigned long TAIOUSB_FlashEraseSector(unsigned long DeviceIndex, signed long Sector);

typedef unsigned long TGenericVendorRead(unsigned long DeviceIndex, unsigned char Request, unsigned short Value, unsigned short Index, unsigned long *pDataSize, void *pData);
typedef unsigned long TGenericVendorWrite(unsigned long DeviceIndex, unsigned char Request, unsigned short Value, unsigned short Index, unsigned long DataSize, void *pData);
typedef unsigned long TAWU_GenericBulkIn(unsigned long DeviceIndex, unsigned long PipeID, void *pData, unsigned long DataSize, unsigned long *pBytesRead);
typedef unsigned long TAWU_GenericBulkOut(unsigned long DeviceIndex, unsigned long PipeID, void *pData, unsigned long DataSize, unsigned long *pBytesWritten);



typedef unsigned long TADC_GetScan(unsigned long DeviceIndex, unsigned short *pBuf);
typedef unsigned long TADC_GetScanV(unsigned long DeviceIndex, double *pBuf);
typedef unsigned long TADC_GetChannelV(unsigned long DeviceIndex, unsigned long ChannelIndex, double *pBuf);
typedef unsigned long TADC_GetCalRefV(unsigned long DeviceIndex, unsigned long CalRefIndex, double *pRef);

typedef unsigned long TADC_GetTrigScan(unsigned long DeviceIndex, unsigned short *pBuf, long TimeoutMS);
typedef unsigned long TADC_GetTrigScanV(unsigned long DeviceIndex, double *pBuf, long TimeoutMS);

typedef unsigned long TADC_GetConfig(unsigned long DeviceIndex, void *pConfigBuf, unsigned long *ConfigBufSize);
typedef unsigned long TADC_SetConfig(unsigned long DeviceIndex, void *pConfigBuf, unsigned long *ConfigBufSize);
typedef unsigned long TADC_ADMode(unsigned long DeviceIndex, unsigned char TriggerMode, unsigned char CalMode);
typedef unsigned long TADC_Range1(unsigned long DeviceIndex, unsigned long ADChannel, unsigned char GainCode, unsigned long bDifferential);
typedef unsigned long TADC_RangeAll(unsigned long DeviceIndex, unsigned char *pGainCodes, unsigned long bDifferential);
typedef unsigned long TADC_SetScanLimits(unsigned long DeviceIndex, unsigned long StartChannel, unsigned long EndChannel);
typedef unsigned long TADC_SetOversample(unsigned long DeviceIndex, unsigned char Oversample);
typedef unsigned long TADC_QueryCal(unsigned long DeviceIndex);
typedef unsigned long TADC_SetCal(unsigned long DeviceIndex, char *CalFileName);
typedef unsigned long TADC_SetCalAndSave(unsigned long DeviceIndex, char *CalFileName, char *SaveCalFileName);
typedef unsigned long TADC_Initialize(unsigned long DeviceIndex, void *pConfigBuf, unsigned long *ConfigBufSize, char *CalFileName);
typedef unsigned long TADC_GetImmediate(unsigned long DeviceIndex, unsigned long Channel, unsigned short *pBuf);

typedef unsigned long TADC_BulkAcquire(unsigned long DeviceIndex, unsigned long BufSize, void *pBuf);
typedef unsigned long TADC_BulkPoll(unsigned long DeviceIndex, unsigned long *BytesLeft);
typedef unsigned long TADC_BulkAbort(unsigned long DeviceIndex);

typedef unsigned long TADC_BulkMode(unsigned long DeviceIndex, unsigned long BulkMode);
typedef unsigned long TADC_BulkContinuousCallbackStart(unsigned long DeviceIndex, unsigned long BufSize, unsigned long BaseBufCount, unsigned long Context, void *pCallback);
typedef unsigned long TADC_BulkContinuousCallbackStartClocked(unsigned long DeviceIndex, unsigned long BufSize, unsigned long BaseBufCount, unsigned long Context, void *pCallback, double *Hz);
typedef unsigned long TADC_BulkContinuousRingStart(unsigned long DeviceIndex, unsigned long RingBufferSize, unsigned long PacketsPerBlock);
typedef unsigned long TADC_BulkContinuousEnd(unsigned long DeviceIndex, unsigned long *pIOStatus);

typedef unsigned long TADC_FullStartRing(unsigned long DeviceIndex, void *pConfigBuf, unsigned long *ConfigBufSize, char *CalFileName, double *pCounterHz, unsigned long RingBufferSize, unsigned long PacketsPerBlock);
typedef unsigned long TADC_ReadData(unsigned long DeviceIndex, void *pConfigBuf, unsigned long *ScansToRead, double *pData, double Timeout);

typedef unsigned long TADC_InitFastITScanV(unsigned long DeviceIndex);
typedef unsigned long TADC_ResetFastITScanV(unsigned long DeviceIndex);
typedef unsigned long TADC_SetFastITScanVChannels(unsigned long DeviceIndex, unsigned long NewChannels);
typedef unsigned long TADC_GetFastITScanV(unsigned long DeviceIndex, double *pBuf);
typedef unsigned long TADC_GetITScanV(unsigned long DeviceIndex, double *pBuf);

typedef unsigned long TADC_InitFastScanV(unsigned long DeviceIndex);
typedef unsigned long TADC_ResetFastScanV(unsigned long DeviceIndex);
typedef unsigned long TADC_GetFastScanV(unsigned long DeviceIndex, double *pBuf);



typedef unsigned long TCTR_8254Load(unsigned long DeviceIndex, unsigned long BlockIndex, unsigned long CounterIndex, unsigned short LoadValue);
typedef unsigned long TCTR_8254Mode(unsigned long DeviceIndex, unsigned long BlockIndex, unsigned long CounterIndex, unsigned long Mode);
typedef unsigned long TCTR_8254ModeLoad(unsigned long DeviceIndex, unsigned long BlockIndex, unsigned long CounterIndex, unsigned long Mode, unsigned short LoadValue);
typedef unsigned long TCTR_8254Read(unsigned long DeviceIndex, unsigned long BlockIndex, unsigned long CounterIndex, unsigned short *pReadValue);
typedef unsigned long TCTR_8254ReadStatus(unsigned long DeviceIndex, unsigned long BlockIndex, unsigned long CounterIndex, unsigned short *pReadValue, unsigned char *pStatus);
typedef unsigned long TCTR_8254ReadModeLoad(unsigned long DeviceIndex, unsigned long BlockIndex, unsigned long CounterIndex, unsigned long Mode, unsigned short LoadValue, unsigned short *pReadValue);

typedef unsigned long TCTR_StartOutputFreq(unsigned long DeviceIndex, unsigned long CounterIndex, double *pHz);

typedef unsigned long TCTR_8254ReadAll(unsigned long DeviceIndex, unsigned short *pData);

typedef unsigned long TCTR_8254SelectGate(unsigned long DeviceIndex, unsigned long GateIndex);
typedef unsigned long TCTR_8254ReadLatched(unsigned long DeviceIndex, unsigned short *pData);
typedef unsigned long TCTR_SetWaitGates(unsigned long DeviceIndex, unsigned char A, unsigned char B);
typedef unsigned long TCTR_EndWaitGates(unsigned long DeviceIndex);
typedef unsigned long TCTR_WaitForGate(unsigned long DeviceIndex, unsigned char GateIndex, unsigned short *pContent);

typedef unsigned long TCTR_StartMeasuringPulseWidth(unsigned long DeviceIndex);
typedef unsigned long TCTR_StopMeasuringPulseWidth(unsigned long DeviceIndex);
typedef unsigned long TCTR_GetPulseWidthMeasurement(unsigned long DeviceIndex, unsigned long BlockIndex, unsigned long CounterIndex, unsigned short *pReadValue);



typedef unsigned long TDIO_Configure(unsigned long DeviceIndex, unsigned char bTristate, void *pOutMask, void *pData);
typedef unsigned long TDIO_ConfigureEx(unsigned long DeviceIndex, void *pOutMask, void *pData, void *pTristateMask);
typedef unsigned long TDIO_ConfigureMasked(unsigned long DeviceIndex, void *pOuts, void *pOutsMask, void *pData, void *pDataMask, void *pTristates, void *pTristatesMask);
typedef unsigned long TDIO_ConfigurationQuery(unsigned long DeviceIndex, void *pOutMask, void *pTristateMask);

typedef unsigned long TDIO_Read1(unsigned long DeviceIndex, unsigned long BitIndex, unsigned char *Buffer);
typedef unsigned long TDIO_Read8(unsigned long DeviceIndex, unsigned long ByteIndex, unsigned char *pBuffer);
typedef unsigned long TDIO_ReadAll(unsigned long DeviceIndex, void *Buffer);

typedef unsigned long TDIO_Write1(unsigned long DeviceIndex, unsigned long BitIndex, unsigned char bData);
typedef unsigned long TDIO_Write8(unsigned long DeviceIndex, unsigned long ByteIndex, unsigned char Data);
typedef unsigned long TDIO_WriteAll(unsigned long DeviceIndex, void *pData);



typedef unsigned long TDIO_StreamOpen(unsigned long DeviceIndex, unsigned long bIsRead);
typedef unsigned long TDIO_StreamClose(unsigned long DeviceIndex);
typedef unsigned long TDIO_StreamFrame(unsigned long DeviceIndex, unsigned long FramePoints, unsigned short *pFrameData, unsigned long *BytesTransferred);
typedef unsigned long TDIO_StreamSetClocks(unsigned long DeviceIndex, double *ReadClockHz, double *WriteClockHz);

typedef unsigned long TDIO_SPI_Read(unsigned long DeviceIndex, unsigned char Address, unsigned char Reg, unsigned char * pValue);
typedef unsigned long TDIO_SPI_Write(unsigned long DeviceIndex, unsigned char Address, unsigned char Reg, unsigned char Value);

typedef unsigned long TDIO_CSA_DoSync(unsigned long DeviceIndex, double * BaseRateHz, double * DurAms, double * DurBms, double * DurCms);
typedef unsigned long TDIO_CSA_DebounceSet(unsigned long DeviceIndex, unsigned long DebounceCounts);
typedef unsigned long TDIO_CSA_DebounceReadAll(unsigned long DeviceIndex, void *pData);

typedef unsigned long TDAC_CSA_SetRangeLimits(unsigned long DeviceIndex, unsigned char *pData);
typedef unsigned long TDAC_CSA_ClearRangeLimits(unsigned long DeviceIndex);

typedef unsigned long TDACDIO_WriteAll(unsigned long DeviceIndex, unsigned short *pDACCounts, unsigned char *pDIOData);



typedef unsigned long TDACDirect(unsigned long DeviceIndex, unsigned long Channel, unsigned short Counts);
typedef unsigned long TDACMultiDirect(unsigned long DeviceIndex, void *pDACData, unsigned long DACDataCount);
typedef unsigned long TDACSetBoardRange(unsigned long DeviceIndex, unsigned long RangeCode);
typedef unsigned long TDACSetChannelCal(unsigned long DeviceIndex, unsigned long Channel, char *CalFileName);

typedef unsigned long TDACOutputProcess(unsigned long DeviceIndex, double *ClockHz, unsigned long NumSamples, unsigned short *SampleData);

typedef unsigned long TDACOutputOpen(unsigned long DeviceIndex, double *ClockHz);
typedef unsigned long TDACOutputClose(unsigned long DeviceIndex, unsigned long bWait);
typedef unsigned long TDACOutputCloseNoEnd(unsigned long DeviceIndex, unsigned long bWait);
typedef unsigned long TDACOutputFrame(unsigned long DeviceIndex, unsigned long FramePoints, unsigned short *FrameData);
typedef unsigned long TDACOutputFrameRaw(unsigned long DeviceIndex, unsigned long FramePoints, unsigned short *FrameData);
typedef unsigned long TDACOutputSetCount(unsigned long DeviceIndex, unsigned long NewCount);
typedef unsigned long TDACOutputStart(unsigned long DeviceIndex);
typedef unsigned long TDACOutputSetInterlock(unsigned long DeviceIndex, unsigned long bInterlock);
typedef unsigned long TDACOutputSetClock(unsigned long DeviceIndex, double *ClockHz);



extern TGetDevices	GetDevices;
extern TQueryDeviceInfo	QueryDeviceInfo;
extern TAIOUSB_CloseDevice	AIOUSB_CloseDevice;
extern TClearDevices	ClearDevices;
extern TGetDeviceUniqueStr	GetDeviceUniqueStr;
extern TGetDeviceSerialNumber	GetDeviceSerialNumber;
extern TResolveDeviceIndex	ResolveDeviceIndex;
extern TGetDeviceByEEPROMByte	GetDeviceByEEPROMByte;
extern TGetDeviceByEEPROMData	GetDeviceByEEPROMData;
extern TGetDeviceBySerialNumber	GetDeviceBySerialNumber;

extern TAIOUSB_ClearFIFO	AIOUSB_ClearFIFO;
extern TAIOUSB_GetStreamStatus	AIOUSB_GetStreamStatus;
extern TAIOUSB_SetStreamingBlockSize	AIOUSB_SetStreamingBlockSize;
extern TAIOUSB_ResetChip	AIOUSB_ResetChip;
extern TAIOUSB_ReloadDeviceLinks	AIOUSB_ReloadDeviceLinks;
extern TAIOUSB_UploadD15LoFirmwaresByPID	AIOUSB_UploadD15LoFirmwaresByPID;

extern TAIOUSB_QuerySimplePNPData	AIOUSB_QuerySimplePNPData;

extern TCustomEEPROMRead	CustomEEPROMRead;
extern TCustomEEPROMWrite	CustomEEPROMWrite;
extern TAIOUSB_FlashRead	AIOUSB_FlashRead;
extern TAIOUSB_FlashWrite	AIOUSB_FlashWrite;
extern TAIOUSB_FlashEraseSector	AIOUSB_FlashEraseSector;

extern TGenericVendorRead	GenericVendorRead;
extern TGenericVendorWrite	GenericVendorWrite;
extern TAWU_GenericBulkIn	AWU_GenericBulkIn;
extern TAWU_GenericBulkOut	AWU_GenericBulkOut;



extern TADC_GetScan	ADC_GetScan;
extern TADC_GetScanV	ADC_GetScanV;
extern TADC_GetChannelV	ADC_GetChannelV;
extern TADC_GetCalRefV	ADC_GetCalRefV;

extern TADC_GetTrigScan	ADC_GetTrigScan;
extern TADC_GetTrigScanV	ADC_GetTrigScanV;

extern TADC_GetConfig	ADC_GetConfig;
extern TADC_SetConfig	ADC_SetConfig;
extern TADC_ADMode	ADC_ADMode;
extern TADC_Range1	ADC_Range1;
extern TADC_RangeAll	ADC_RangeAll;
extern TADC_SetScanLimits	ADC_SetScanLimits;
extern TADC_SetOversample	ADC_SetOversample;
extern TADC_QueryCal	ADC_QueryCal;
extern TADC_SetCal	ADC_SetCal;
extern TADC_SetCalAndSave	ADC_SetCalAndSave;
extern TADC_Initialize	ADC_Initialize;
extern TADC_GetImmediate	ADC_GetImmediate;

extern TADC_BulkAcquire	ADC_BulkAcquire;
extern TADC_BulkPoll	ADC_BulkPoll;
extern TADC_BulkAbort	ADC_BulkAbort;

extern TADC_BulkMode	ADC_BulkMode;
extern TADC_BulkContinuousCallbackStart	ADC_BulkContinuousCallbackStart;
extern TADC_BulkContinuousCallbackStartClocked	ADC_BulkContinuousCallbackStartClocked;
extern TADC_BulkContinuousRingStart	ADC_BulkContinuousRingStart;
extern TADC_BulkContinuousEnd	ADC_BulkContinuousEnd;

extern TADC_FullStartRing	ADC_FullStartRing;
extern TADC_ReadData	ADC_ReadData;

extern TADC_InitFastITScanV	ADC_InitFastITScanV;
extern TADC_ResetFastITScanV	ADC_ResetFastITScanV;
extern TADC_SetFastITScanVChannels	ADC_SetFastITScanVChannels;
extern TADC_GetFastITScanV	ADC_GetFastITScanV;
extern TADC_GetITScanV	ADC_GetITScanV;

extern TADC_InitFastScanV	ADC_InitFastScanV;
extern TADC_ResetFastScanV	ADC_ResetFastScanV;
extern TADC_GetFastScanV	ADC_GetFastScanV;



extern TCTR_8254Load	CTR_8254Load;
extern TCTR_8254Mode	CTR_8254Mode;
extern TCTR_8254ModeLoad	CTR_8254ModeLoad;
extern TCTR_8254Read	CTR_8254Read;
extern TCTR_8254ReadStatus	CTR_8254ReadStatus;
extern TCTR_8254ReadModeLoad	CTR_8254ReadModeLoad;

extern TCTR_StartOutputFreq	CTR_StartOutputFreq;

extern TCTR_8254ReadAll	CTR_8254ReadAll;

extern TCTR_8254SelectGate	CTR_8254SelectGate;
extern TCTR_8254ReadLatched	CTR_8254ReadLatched;
extern TCTR_SetWaitGates	CTR_SetWaitGates;
extern TCTR_EndWaitGates	CTR_EndWaitGates;
extern TCTR_WaitForGate	CTR_WaitForGate;

extern TCTR_StartMeasuringPulseWidth	CTR_StartMeasuringPulseWidth;
extern TCTR_StopMeasuringPulseWidth	CTR_StopMeasuringPulseWidth;
extern TCTR_GetPulseWidthMeasurement	CTR_GetPulseWidthMeasurement;



extern TDIO_Configure	DIO_Configure;
extern TDIO_ConfigureEx	DIO_ConfigureEx;
extern TDIO_ConfigureMasked	DIO_ConfigureMasked;
extern TDIO_ConfigurationQuery	DIO_ConfigurationQuery;

extern TDIO_Read1	DIO_Read1;
extern TDIO_Read8	DIO_Read8;
extern TDIO_ReadAll	DIO_ReadAll;

extern TDIO_Write1	DIO_Write1;
extern TDIO_Write8	DIO_Write8;
extern TDIO_WriteAll	DIO_WriteAll;



extern TDIO_StreamOpen	DIO_StreamOpen;
extern TDIO_StreamClose	DIO_StreamClose;
extern TDIO_StreamFrame	DIO_StreamFrame;
extern TDIO_StreamSetClocks	DIO_StreamSetClocks;

extern TDIO_SPI_Read	DIO_SPI_Read;
extern TDIO_SPI_Write	DIO_SPI_Write;

extern TDIO_CSA_DoSync	DIO_CSA_DoSync;
extern TDIO_CSA_DebounceSet	DIO_CSA_DebounceSet;
extern TDIO_CSA_DebounceReadAll	DIO_CSA_DebounceReadAll;

extern TDAC_CSA_SetRangeLimits	DAC_CSA_SetRangeLimits;
extern TDAC_CSA_ClearRangeLimits	DAC_CSA_ClearRangeLimits;

extern TDACDIO_WriteAll	DACDIO_WriteAll;



extern TDACDirect	DACDirect;
extern TDACMultiDirect	DACMultiDirect;
extern TDACSetBoardRange	DACSetBoardRange;
extern TDACSetChannelCal	DACSetChannelCal;

extern TDACOutputProcess	DACOutputProcess;

extern TDACOutputOpen	DACOutputOpen;
extern TDACOutputClose	DACOutputClose;
extern TDACOutputCloseNoEnd	DACOutputCloseNoEnd;
extern TDACOutputFrame	DACOutputFrame;
extern TDACOutputFrameRaw	DACOutputFrameRaw;
extern TDACOutputSetCount	DACOutputSetCount;
extern TDACOutputStart	DACOutputStart;
extern TDACOutputSetInterlock	DACOutputSetInterlock;
extern TDACOutputSetClock	DACOutputSetClock;



//Note that all error codes returned are Windows error codes; they can be found in winerror.h in the Windows SDK, or on the Web.
